"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const CopyManager_1 = __importDefault(require("../sync-managers/CopyManager"));
const syncDiff_1 = __importDefault(require("../helpers/syncDiff"));
const BucketHelper_1 = require("../helpers/BucketHelper");
function bucketWithBucket(sourceBucketPrefix, targetBucketPrefix, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const { commandInput, del = false, dryRun = false, sizeOnly = false, maxConcurrentTransfers = constants_1.DEFAULT_MAX_CONCURRENT_TRANSFERS, monitor, relocations = [], filters = [], } = options;
        const { bucket: sourceBucket, prefix: sourcePrefix } = BucketHelper_1.BucketHelper.parsePrefix(sourceBucketPrefix);
        const { bucket: targetBucket, prefix: targetPrefix } = BucketHelper_1.BucketHelper.parsePrefix(targetBucketPrefix);
        const [sourceObjects, targetObjects] = yield Promise.all([
            this.listBucketObjects(sourceBucket, { prefix: sourcePrefix }),
            this.listBucketObjects(targetBucket, { prefix: targetPrefix }),
        ]);
        if (targetPrefix !== '') {
            relocations.push(['', targetPrefix]);
        }
        sourceObjects.forEach((sourceObject) => sourceObject.applyFilters(filters));
        const includedSourceObjects = sourceObjects.filter((sourceObject) => sourceObject.isIncluded());
        includedSourceObjects.forEach((sourceObject) => sourceObject.applyRelocations(relocations));
        let pCopy;
        const { created, updated, deleted } = (0, syncDiff_1.default)(includedSourceObjects, targetObjects, sizeOnly);
        const copies = [...created, ...updated];
        if (!dryRun) {
            const copyManager = new CopyManager_1.default({
                client: this.client,
                objects: copies,
                commandInput,
                maxConcurrentTransfers,
                monitor,
                targetBucket,
            });
            pCopy = copyManager.done();
        }
        let pDelete;
        let deletions = [];
        if (del) {
            deletions = deleted;
            if (!dryRun) {
                const keysToDelete = deletions.map(({ key }) => key);
                pDelete = this.deleteBucketObjects(targetBucket, keysToDelete);
            }
        }
        yield Promise.all([pCopy, pDelete]);
        return { copies, deletions };
    });
}
exports.default = bucketWithBucket;
//# sourceMappingURL=bucketWithBucket.js.map