"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const UploadManager_1 = __importDefault(require("../sync-managers/UploadManager"));
const syncDiff_1 = __importDefault(require("../helpers/syncDiff"));
const BucketHelper_1 = require("../helpers/BucketHelper");
function bucketWithLocal(localDir, bucketPrefix, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const { commandInput, del = false, dryRun = false, sizeOnly = false, maxConcurrentTransfers = constants_1.DEFAULT_MAX_CONCURRENT_TRANSFERS, monitor, partSize = constants_1.DEFAULT_PART_SIZE, relocations = [], filters = [], } = options;
        const { bucket, prefix } = (0, BucketHelper_1.parsePrefix)(bucketPrefix);
        const [sourceObjects, targetObjects] = yield Promise.all([
            this.listLocalObjects(localDir),
            this.listBucketObjects(bucket, { prefix }),
        ]);
        if (prefix !== '') {
            relocations.push(['', prefix]);
        }
        sourceObjects.forEach((sourceObject) => sourceObject.applyFilters(filters));
        const includedSourceObjects = sourceObjects.filter((sourceObject) => sourceObject.isIncluded());
        includedSourceObjects.forEach((sourceObject) => sourceObject.applyRelocations(relocations));
        let pUpload;
        const { created, updated, deleted } = (0, syncDiff_1.default)(includedSourceObjects, targetObjects, sizeOnly);
        const uploads = [...created, ...updated];
        if (!dryRun) {
            const transferManager = new UploadManager_1.default({
                client: this.client,
                objects: uploads,
                commandInput,
                maxConcurrentTransfers,
                monitor,
                partSize,
                bucket,
            });
            pUpload = transferManager.done();
        }
        let pDelete;
        let deletions = [];
        if (del) {
            deletions = deleted;
            if (!dryRun) {
                const keysToDelete = deletions.map(({ key }) => key);
                pDelete = this.deleteBucketObjects(bucket, keysToDelete);
            }
        }
        yield Promise.all([pUpload, pDelete]);
        return { uploads, deletions };
    });
}
exports.default = bucketWithLocal;
//# sourceMappingURL=bucketWithLocal.js.map