"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fs_1 = require("node:fs");
const constants_1 = require("../constants");
const DownloadManager_1 = __importDefault(require("../sync-managers/DownloadManager"));
const syncDiff_1 = __importDefault(require("../helpers/syncDiff"));
const BucketHelper_1 = require("../helpers/BucketHelper");
function localWithBucket(bucketPrefix, localDir, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const { bucket, prefix } = (0, BucketHelper_1.parsePrefix)(bucketPrefix);
        const { commandInput, del = false, dryRun = false, sizeOnly = false, maxConcurrentTransfers = constants_1.DEFAULT_MAX_CONCURRENT_TRANSFERS, monitor, relocations = [], filters = [], } = options;
        yield node_fs_1.promises.mkdir(localDir, { recursive: true });
        const [sourceObjects, targetObjects] = yield Promise.all([
            this.listBucketObjects(bucket, { prefix }),
            this.listLocalObjects(localDir),
        ]);
        sourceObjects.forEach((sourceObject) => sourceObject.applyFilters(filters));
        const includedSourceObjects = sourceObjects.filter((sourceObject) => sourceObject.isIncluded());
        includedSourceObjects.forEach((sourceObject) => {
            sourceObject.applyRelocations(relocations);
        });
        let pDownload;
        const { created, updated, deleted } = (0, syncDiff_1.default)(includedSourceObjects, targetObjects, sizeOnly);
        const downloads = [...created, ...updated];
        if (!dryRun) {
            const downloadManager = new DownloadManager_1.default({
                client: this.client,
                objects: downloads,
                commandInput,
                maxConcurrentTransfers,
                monitor,
                localDir,
            });
            pDownload = downloadManager.done();
        }
        let pDelete;
        let deletions = [];
        if (del) {
            deletions = deleted;
            if (!dryRun) {
                const filesToDelete = deletions.map(({ path: filePath }) => filePath);
                pDelete = Promise.all(filesToDelete.map((filePath) => node_fs_1.promises.unlink(filePath)));
            }
        }
        yield Promise.all([pDownload, pDelete]);
        return { downloads, deletions };
    });
}
exports.default = localWithBucket;
//# sourceMappingURL=localWithBucket.js.map