"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncObject = void 0;
class SyncObject {
    id;
    size;
    lastModified;
    isExcluded = false;
    constructor(options) {
        this.id = options.id;
        this.size = options.size;
        this.lastModified = options.lastModified;
    }
    static diff(sourceObjects, targetObjects, sizeOnly = false) {
        const sourceObjectMap = new Map(sourceObjects.map((sourceObject) => [sourceObject.id, sourceObject]));
        const targetObjectMap = new Map(targetObjects.map((targetObject) => [targetObject.id, targetObject]));
        const created = [];
        const updated = [];
        sourceObjectMap.forEach((sourceObject) => {
            const targetObject = targetObjectMap.get(sourceObject.id);
            if (targetObject === undefined) {
                created.push(sourceObject);
            }
            else if (sourceObject.size !== targetObject.size ||
                (!sizeOnly && sourceObject.lastModified > targetObject.lastModified)) {
                updated.push(sourceObject);
            }
        });
        const deleted = [];
        targetObjectMap.forEach((targetObject) => {
            if (!sourceObjectMap.has(targetObject.id)) {
                deleted.push(targetObject);
            }
        });
        return { created, updated, deleted };
    }
    get isIncluded() {
        return !this.isExcluded;
    }
    applyFilters(filters) {
        filters.forEach(({ include, exclude }) => {
            if (!this.isExcluded && exclude != null) {
                this.isExcluded = exclude(this.id);
            }
            if (this.isExcluded && include) {
                this.isExcluded = !include(this.id);
            }
        });
    }
    applyRelocation(sourcePrefix, targetPrefix) {
        if (sourcePrefix === '' && targetPrefix !== '') {
            this.id = `${targetPrefix}/${this.id}`;
        }
        if (this.id.startsWith(`${sourcePrefix}/`)) {
            if (targetPrefix === '') {
                this.id = this.id.slice(sourcePrefix.length + 1);
            }
            this.id = this.id.replace(sourcePrefix, targetPrefix);
        }
    }
    applyRelocations(relocations) {
        relocations.forEach(([sourcePrefix, targetPrefix]) => {
            this.applyRelocation(sourcePrefix, targetPrefix);
        });
    }
}
exports.SyncObject = SyncObject;
//# sourceMappingURL=SyncObject.js.map