"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const abort_controller_1 = require("@aws-sdk/abort-controller");
const constants_1 = require("../constants");
class TransferManager {
    constructor(options = {}) {
        this.monitor = null;
        const { client, commandInput, maxConcurrentTransfers = constants_1.DEFAULT_MAX_CONCURRENT_TRANSFERS, monitor, objects, } = options;
        this.client = client;
        this.commandInput = commandInput;
        this.maxConcurrentTransfers = maxConcurrentTransfers;
        this.objects = objects;
        this.abortController = new abort_controller_1.AbortController();
        this.monitor = monitor;
        if (this.monitor) {
            const totalDataSize = this.objects.reduce((total, { size }) => total + size, 0);
            this.monitor.emit('metadata', totalDataSize, this.objects.length);
            this.monitor.on('abort', this.abort.bind(this));
        }
    }
    abort() {
        this.abortController.abort();
    }
}
exports.default = TransferManager;
//# sourceMappingURL=TransferManager.js.map