"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const TransferManager_1 = __importDefault(require("./TransferManager"));
const async_map_1 = __importDefault(require("../helpers/async-map"));
const defer_1 = __importDefault(require("../helpers/defer"));
class UploadManager extends TransferManager_1.default {
    constructor(options = {}) {
        super(options);
        const { bucket, partSize = constants_1.DEFAULT_PART_SIZE, } = options;
        this.bucket = bucket;
        this.partSize = partSize;
    }
    deferCreateMultipartUpload(object) {
        return (0, defer_1.default)(() => __awaiter(this, void 0, void 0, function* () {
            return object.createMultipartUpload({
                client: this.client,
                bucket: this.bucket,
                commandInput: this.commandInput,
            });
        }));
    }
    deferUploadPart(object, options = {}) {
        const { start, end, partNumber, createMultipartUploadPromise, } = options;
        return (0, defer_1.default)(() => __awaiter(this, void 0, void 0, function* () {
            const { uploadId } = yield createMultipartUploadPromise;
            return object.uploadPart({
                client: this.client,
                bucket: this.bucket,
                commandInput: this.commandInput,
                monitor: this.monitor,
                abortSignal: this.abortController.signal,
                start,
                end,
                uploadId,
                partNumber,
            });
        }));
    }
    deferCompleteMultipartUpload(object, options = {}) {
        const { createMultipartUploadPromise, uploadPartPromises, } = options;
        return (0, defer_1.default)(() => __awaiter(this, void 0, void 0, function* () {
            const { uploadId } = yield createMultipartUploadPromise;
            const uploadedParts = yield Promise.all(uploadPartPromises);
            return object.completeMultipartUpload({
                client: this.client,
                bucket: this.bucket,
                uploadId,
                uploadedParts,
            });
        }));
    }
    createMultipartUploadPromises(object) {
        const deferredCreateMultipartUpload = this.deferCreateMultipartUpload(object);
        const deferredUploadParts = object.getPartOffsets(this.partSize)
            .map(({ start, end }, index) => this.deferUploadPart(object, {
            start,
            end,
            partNumber: index + 1,
            createMultipartUploadPromise: deferredCreateMultipartUpload.promise,
        }));
        const deferredCompleteMultipartUpload = this.deferCompleteMultipartUpload(object, {
            createMultipartUploadPromise: deferredCreateMultipartUpload.promise,
            uploadPartPromises: deferredUploadParts.map(({ promise }) => promise),
        });
        return [
            deferredCreateMultipartUpload.resolve,
            ...deferredUploadParts.map(({ resolve }) => resolve),
            deferredCompleteMultipartUpload.resolve,
        ];
    }
    done() {
        return __awaiter(this, void 0, void 0, function* () {
            const uploadOps = [];
            this.objects.forEach((object) => {
                if (object.size > this.partSize) {
                    uploadOps.push(...this.createMultipartUploadPromises(object));
                }
                else {
                    uploadOps.push(() => __awaiter(this, void 0, void 0, function* () {
                        return object.upload({
                            client: this.client,
                            bucket: this.bucket,
                            commandInput: this.commandInput,
                            monitor: this.monitor,
                            abortSignal: this.abortController.signal,
                        });
                    }));
                }
            });
            yield (0, async_map_1.default)(uploadOps, this.maxConcurrentTransfers, (uploadOp) => __awaiter(this, void 0, void 0, function* () { return uploadOp(); }));
        });
    }
}
exports.default = UploadManager;
//# sourceMappingURL=UploadManager.js.map