"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BucketObject = void 0;
const fs = __importStar(require("node:fs"));
const node_fs_1 = require("node:fs");
const path = __importStar(require("node:path"));
const client_s3_1 = require("@aws-sdk/client-s3");
const CommandInputHelper_1 = require("../helpers/CommandInputHelper");
const PathHelper_1 = require("../helpers/PathHelper");
const SyncObject_1 = require("./SyncObject");
class BucketObject extends SyncObject_1.SyncObject {
    constructor(options) {
        super(options);
        this.bucket = options.bucket;
        this.key = options.key;
    }
    download(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const relativePath = PathHelper_1.PathHelper.toLocalPath(this.id);
            const filePath = path.join(options.localDir, relativePath);
            yield node_fs_1.promises.mkdir(path.dirname(filePath), { recursive: true });
            const getObjectCommandInput = CommandInputHelper_1.CommandInputHelper.merge({
                Bucket: this.bucket,
                Key: this.key,
            }, options.commandInput);
            const response = yield options.client.send(new client_s3_1.GetObjectCommand(getObjectCommandInput), { abortSignal: options.abortSignal });
            const readStream = response.Body;
            const { LastModified } = response;
            const writeStream = readStream.pipe(fs.createWriteStream(filePath));
            if (options.monitor) {
                readStream.on('data', (data) => {
                    options.monitor.emit('size', data.length);
                });
                writeStream.on('finish', () => {
                    options.monitor.emit('object');
                });
            }
            yield new Promise((resolve, reject) => {
                writeStream.on('error', reject);
                writeStream.on('finish', () => {
                    fs.utimes(filePath, LastModified, LastModified, (err) => {
                        if (err)
                            reject(err);
                        else
                            resolve();
                    });
                });
            });
        });
    }
    copy(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const copyObjectCommandInput = CommandInputHelper_1.CommandInputHelper.merge({
                Bucket: options.targetBucket,
                Key: this.id,
                CopySource: encodeURI(`${this.bucket}/${this.key}`),
            }, options.commandInput);
            yield options.client.send(new client_s3_1.CopyObjectCommand(copyObjectCommandInput), {
                abortSignal: options.abortSignal,
            });
            if (options.monitor) {
                options.monitor.emit('size', this.size);
                options.monitor.emit('object');
            }
        });
    }
}
exports.BucketObject = BucketObject;
exports.default = BucketObject;
//# sourceMappingURL=BucketObject.js.map