"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncObject = void 0;
class SyncObject {
    constructor(options) {
        this.isExcluded = false;
        this.id = options.id;
        this.size = options.size;
        this.lastModified = options.lastModified;
    }
    get isIncluded() {
        return !this.isExcluded;
    }
    relocate(sourcePrefix, targetPrefix) {
        if (sourcePrefix === '' && targetPrefix !== '') {
            this.id = `${targetPrefix}/${this.id}`;
        }
        if (this.id.startsWith(`${sourcePrefix}/`)) {
            if (targetPrefix === '') {
                this.id = this.id.slice(sourcePrefix.length + 1);
            }
            this.id = this.id.replace(sourcePrefix, targetPrefix);
        }
    }
    applyFilters(filters) {
        filters.forEach(({ include, exclude }) => {
            if (!this.isExcluded && exclude != null) {
                this.isExcluded = exclude(this.id);
            }
            if (this.isExcluded && include) {
                this.isExcluded = !include(this.id);
            }
        });
    }
    applyRelocations(relocations) {
        relocations.forEach(([sourcePrefix, targetPrefix]) => {
            this.relocate(sourcePrefix, targetPrefix);
        });
    }
}
exports.SyncObject = SyncObject;
exports.default = SyncObject;
//# sourceMappingURL=SyncObject.js.map