/// <reference types="node" />
import { CreateMultipartUploadCommandInput, PutObjectCommandInput, S3Client, UploadPartCommandInput } from '@aws-sdk/client-s3';
import { AbortSignal } from '@aws-sdk/abort-controller';
import { Readable } from 'node:stream';
import { SyncObject, SyncObjectOptions } from './SyncObject';
import { TransferMonitor } from '../TransferMonitor';
export type LocalObjectOptions = {
    path: string;
} & SyncObjectOptions;
export type LocalObjectUploadOptions = {
    client: S3Client;
    bucket: string;
    abortSignal?: AbortSignal;
    commandInput?: PutObjectCommandInput;
    monitor?: TransferMonitor;
};
export type UploadedPart = {
    eTag: string;
    partNumber: number;
};
export type PartOffset = {
    start: number;
    end: number;
};
export type CreateMultipartUploadOptions = {
    client: S3Client;
    bucket: string;
    commandInput?: CreateMultipartUploadCommandInput;
};
export type UploadPartOptions = {
    client: S3Client;
    bucket: string;
    abortSignal?: AbortSignal;
    commandInput?: UploadPartCommandInput;
    monitor?: TransferMonitor;
    start: number;
    end: number;
    uploadId: string;
    partNumber: number;
};
export type CompleteMultipartUploadOptions = {
    client: S3Client;
    bucket: string;
    uploadId: string;
    uploadedParts: UploadedPart[];
};
export type DecorateUploadStreamOptions = {
    stream: Readable;
    monitor?: TransferMonitor;
};
export declare class LocalObject extends SyncObject {
    path: string;
    constructor(options: LocalObjectOptions);
    static decorateUploadStream(options: DecorateUploadStreamOptions): Promise<void>;
    upload(options: LocalObjectUploadOptions): Promise<void>;
    getPartOffsets(partSize: number): PartOffset[];
    createMultipartUpload(options: CreateMultipartUploadOptions): Promise<{
        uploadId: string;
    }>;
    uploadPart(options: UploadPartOptions): Promise<{
        eTag: string;
        partNumber: number;
    }>;
    completeMultipartUpload(options: CompleteMultipartUploadOptions): Promise<void>;
    delete(): Promise<void>;
}
export default LocalObject;
