"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalObject = void 0;
const fs = __importStar(require("node:fs"));
const node_fs_1 = require("node:fs");
const client_s3_1 = require("@aws-sdk/client-s3");
const CommandInputHelper_1 = require("../helpers/CommandInputHelper");
const SyncObject_1 = require("./SyncObject");
class LocalObject extends SyncObject_1.SyncObject {
    constructor(options) {
        super(options);
        this.path = options.path;
    }
    static decorateUploadStream(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const { stream, monitor } = options;
            if (monitor) {
                stream.on('data', (data) => {
                    monitor.emit('size', data.length);
                });
                stream.pause();
                stream.on('end', () => {
                    monitor.emit('object');
                });
            }
            yield new Promise((resolve, reject) => {
                stream.on('error', reject);
                stream.on('end', resolve);
            });
        });
    }
    upload(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const stream = fs.createReadStream(this.path);
            const putObjectCommandInput = CommandInputHelper_1.CommandInputHelper.merge({
                Bucket: options.bucket,
                Key: this.id,
                Body: stream,
                ContentLength: this.size,
            }, options.commandInput);
            const upload = LocalObject.decorateUploadStream({
                stream,
                monitor: options.monitor,
            });
            yield options.client.send(new client_s3_1.PutObjectCommand(putObjectCommandInput), {
                abortSignal: options.abortSignal,
            });
            yield upload;
        });
    }
    getPartOffsets(partSize) {
        const parts = [];
        for (let i = 0; i < this.size; i += partSize) {
            parts.push({
                start: i,
                end: Math.min(i + partSize - 1, this.size - 1),
            });
        }
        return parts;
    }
    createMultipartUpload(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const uploadCommandInput = CommandInputHelper_1.CommandInputHelper.merge({
                Bucket: options.bucket,
                Key: this.id,
            }, Object.assign(Object.assign({}, options.commandInput), { Body: undefined }));
            const { UploadId: uploadId } = yield options.client.send(new client_s3_1.CreateMultipartUploadCommand(uploadCommandInput));
            return { uploadId };
        });
    }
    uploadPart(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const stream = fs.createReadStream(this.path, {
                start: options.start,
                end: options.end,
            });
            const uploadPartCommandInput = CommandInputHelper_1.CommandInputHelper.merge({
                Bucket: options.bucket,
                Key: this.id,
                UploadId: options.uploadId,
                PartNumber: options.partNumber,
                Body: stream,
                ContentLength: options.end - options.start + 1,
            }, options.commandInput);
            const upload = LocalObject.decorateUploadStream({
                stream,
                monitor: options.monitor,
            });
            const { ETag: eTag } = yield options.client.send(new client_s3_1.UploadPartCommand(uploadPartCommandInput), { abortSignal: options.abortSignal });
            yield upload;
            return { eTag, partNumber: options.partNumber };
        });
    }
    completeMultipartUpload(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const parts = [...options.uploadedParts]
                .sort((a, b) => a.partNumber - b.partNumber)
                .map((part) => ({
                ETag: part.eTag,
                PartNumber: part.partNumber,
            }));
            yield options.client.send(new client_s3_1.CompleteMultipartUploadCommand({
                Bucket: options.bucket,
                Key: this.id,
                UploadId: options.uploadId,
                MultipartUpload: { Parts: parts },
            }));
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield node_fs_1.promises.unlink(this.path);
        });
    }
}
exports.LocalObject = LocalObject;
exports.default = LocalObject;
//# sourceMappingURL=LocalObject.js.map